@@ -13,25 +13,23 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
  
 #include "config.h"
 
-#include <string.h>
-
-#include <glib/gi18n.h>
- 
-#include "seahorse-object-widget.h"
-#include "seahorse-util.h"
-
 #include "seahorse-gpgme-dialogs.h"
 #include "seahorse-gpgme-key-op.h"
 #include "seahorse-gpgme-subkey.h"
 
+#include "libseahorse/seahorse-object-widget.h"
+#include "libseahorse/seahorse-util.h"
+
+#include <glib/gi18n.h>
+
+#include <string.h>
+
 void              on_gpgme_expire_ok_clicked             (GtkButton *button,
                                                           gpointer user_data);
 
@@ -76,7 +74,7 @@ on_gpgme_expire_ok_clicked (GtkButton *button,
 	if (expiry != (time_t)seahorse_pgp_subkey_get_expires (SEAHORSE_PGP_SUBKEY (subkey))) {
 		err = seahorse_gpgme_key_op_set_expires (subkey, expiry);
 		if (!GPG_IS_OK (err))
-			seahorse_gpgme_handle_error (err, _("Couldn't change expiry date"));
+			seahorse_gpgme_handle_error (err, _("Couldn’t change expiry date"));
 	}
     
 	g_object_unref (subkey);
