@@ -41,7 +41,6 @@ enum {
 
 struct _SeahorseKeyserverResultsPrivate {
 	char *search_string;
-	SeahorsePredicate pred;
 	GtkTreeView *view;
 	GcrSimpleCollection *collection;
 	GtkActionGroup *import_actions;
@@ -326,7 +325,6 @@ seahorse_keyserver_results_constructed (GObject *obj)
 
 	self->pv->store = seahorse_key_manager_store_new (GCR_COLLECTION (self->pv->collection),
 	                                                  self->pv->view,
-	                                                  &self->pv->pred,
 	                                                  self->pv->settings);
 	on_view_selection_changed (selection, self);
 
