@@ -13,10 +13,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the
- * Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 #include "config.h"
 
@@ -26,9 +24,8 @@
 #include "seahorse-pgp-uid.h"
 #include "seahorse-pgp-subkey.h"
 
-#include "seahorse-common.h"
-#include "seahorse-object-list.h"
-#include "seahorse-util.h"
+#include "libseahorse/seahorse-object-list.h"
+#include "libseahorse/seahorse-util.h"
 
 #include <gcr/gcr.h>
 
