@@ -22,8 +22,7 @@
 
 #include <glib-object.h>
 
-#include "libseahorse/seahorse-object.h"
-#include "libseahorse/seahorse-validity.h"
+#include "seahorse-common.h"
 
 enum {
     SKEY_PGPSIG_TRUSTED = 0x0001,
