@@ -22,8 +22,7 @@
 
 #include <glib-object.h>
 
-#include "libseahorse/seahorse-object.h"
-#include "libseahorse/seahorse-validity.h"
+#include "seahorse-common.h"
 
 #include "seahorse-pgp-key.h"
 
